package cn.com.qmth.examcloud.ws.core;

import java.util.Map;

import javax.websocket.Session;

import org.apache.commons.io.IOUtils;

import com.google.common.collect.Maps;

/**
 * websocket session管理
 *
 * @author WANGWEI
 * @date 2019年11月22日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
public class SessionHolder {

	private static final Map<String, Session> ID_SESESION_MAP = Maps.newConcurrentMap();

	private static final Map<Session, String> SESESION_ID_MAP = Maps.newConcurrentMap();

	/**
	 * 获取 Session
	 *
	 * @author WANGWEI
	 * @param sessionId
	 * @return
	 */
	public static Session getSession(String sessionId) {
		Session session = ID_SESESION_MAP.get(sessionId);
		return session;
	}

	/**
	 * 获取 sessionId
	 *
	 * @author WANGWEI
	 * @param session
	 * @return
	 */
	public static String getSessionId(Session session) {
		return SESESION_ID_MAP.get(session);
	}

	/**
	 * 重新设置session
	 *
	 * @author WANGWEI
	 * @param sessionId
	 * @param session
	 */
	public static void setSession(String sessionId, Session session) {
		Session oldSession = ID_SESESION_MAP.get(sessionId);
		if (null != oldSession && !oldSession.equals(session)) {
			IOUtils.closeQuietly(oldSession);
			SESESION_ID_MAP.remove(oldSession);
		}

		ID_SESESION_MAP.put(sessionId, session);
		SESESION_ID_MAP.put(session, sessionId);
	}

	/**
	 * 删除 session
	 *
	 * @author WANGWEI
	 * @param sessionId
	 */
	public static void delSession(String sessionId) {
		Session session = ID_SESESION_MAP.get(sessionId);
		ID_SESESION_MAP.remove(sessionId);
		if (null != session) {
			IOUtils.closeQuietly(session);
			SESESION_ID_MAP.remove(session);
		}
	}

	/**
	 * 删除 session
	 *
	 * @author WANGWEI
	 * @param session
	 */
	public static void delSession(Session session) {
		String sessionId = SESESION_ID_MAP.get(session);
		ID_SESESION_MAP.remove(sessionId);

		SESESION_ID_MAP.remove(session);
		IOUtils.closeQuietly(session);
	}

}
